# Tfignite: High-level library to help with training neural networks in tensorflow.

Tfignite is a project that stems from [ignite](https://github.com/pytorch/ignite). Ignite is a high-level library to help with training neural networks in PyTorch, while Tfignite bares similar design / api and is designed dedicated for tensorflow 2.0.

For the full API reference, read the [online documentation](https://ipod825.github.io/tfignite/docs/html/index.html). For example usage, check the [examples](https://github.com/ipod825/tfignite/tree/master/examples) directory.


## Installation

~~~{.bash}
pip install tfignite
~~~
